@@ -1335,6 +1335,8 @@ class GenericJob(JobCore):
         # Different run modes
         if self.server.run_mode.manual:
             self.run_if_manually()
+        elif self.server.run_mode.worker:
+            self.run_if_manually(_manually_print=False)
         elif self.server.run_mode.modal:
             self.run_static()
         elif self.server.run_mode.non_modal or self.server.run_mode.thread:
