@@ -9,6 +9,7 @@ import os
 import logging
 from pyiron_base.project.generic import Project
 from pyiron_base.settings.generic import Settings
+from pyiron_base.database.manager import DatabaseManager
 from pyiron_base.database.filetable import get_hamilton_from_file, get_hamilton_version_from_file, \
     get_job_status_from_file
 
@@ -24,6 +25,7 @@ __status__ = "production"
 __date__ = "Sep 1, 2017"
 
 s = Settings()
+dbm = DatabaseManager()
 
 
 class JobWrapper(object):
@@ -44,12 +46,12 @@ class JobWrapper(object):
         self.working_directory = working_directory
         self._remote_flag = submit_on_remote
         if connection_string is not None:
-            s.open_local_sqlite_connection(connection_string=connection_string)
+            dbm.open_local_sqlite_connection(connection_string=connection_string)
         pr = Project(path=os.path.join(working_directory, '..', '..'))
         if job_id is not None:
             self.job = pr.load(int(job_id))
         else:
-            projectpath = s.top_path(hdf5_file)
+            projectpath = dbm.top_path(hdf5_file)
             if projectpath is None:
                 project = os.path.dirname(hdf5_file)
             else:
@@ -129,9 +131,9 @@ def job_wrapper_function(working_directory, job_id=None, file_path=None, submit_
 
     # always close the database connection in calculations on the cluster to avoid high number of concurrent
     # connections.
-    s.close_connection()
-    s.connection_timeout = 0
-    s.open_connection()
+    dbm.close_connection()
+    dbm.connection_timeout = 0
+    dbm.open_connection()
 
     if job_id is not None:
         job = JobWrapper(
